@@ -1,10 +1,6 @@
 var searchData=
 [
-  ['sameconfiguration',['SameConfiguration',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1SameConfiguration.html',1,'openvdb::v3_2_0::tree::InternalNode']]],
-  ['sameconfiguration',['SameConfiguration',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1SameConfiguration.html',1,'openvdb::v3_2_0::tree::LeafNode']]],
-  ['sameconfiguration',['SameConfiguration',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_3_01ValueMask_00_01Log2Dim_01_4_1_1SameConfiguration.html',1,'openvdb::v3_2_0::tree::LeafNode&lt; ValueMask, Log2Dim &gt;']]],
-  ['sameconfiguration',['SameConfiguration',['../structopenvdb_1_1v3__2__0_1_1tree_1_1RootNode_1_1SameConfiguration.html',1,'openvdb::v3_2_0::tree::RootNode']]],
-  ['sameconfiguration',['SameConfiguration',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_3_01bool_00_01Log2Dim_01_4_1_1SameConfiguration.html',1,'openvdb::v3_2_0::tree::LeafNode&lt; bool, Log2Dim &gt;']]],
+  ['sameconfiguration',['SameConfiguration',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1SameConfiguration.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::SameConfiguration&lt; OtherNodeType &gt;'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1SameConfiguration.html',1,'LeafNode&lt; T, Log2Dim &gt;::SameConfiguration&lt; OtherNodeType &gt;'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_3_01bool_00_01Log2Dim_01_4_1_1SameConfiguration.html',1,'LeafNode&lt; bool, Log2Dim &gt;::SameConfiguration&lt; OtherNodeType &gt;'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_3_01ValueMask_00_01Log2Dim_01_4_1_1SameConfiguration.html',1,'LeafNode&lt; ValueMask, Log2Dim &gt;::SameConfiguration&lt; OtherNodeType &gt;'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1RootNode_1_1SameConfiguration.html',1,'RootNode&lt; ChildType &gt;::SameConfiguration&lt; OtherNodeType &gt;']]],
   ['sameinternalconfig',['SameInternalConfig',['../structopenvdb_1_1v3__2__0_1_1tree_1_1SameInternalConfig.html',1,'openvdb::v3_2_0::tree']]],
   ['sameinternalconfig_3c_20childt1_2c_20dim1_2c_20internalnode_3c_20childt2_2c_20dim1_20_3e_20_3e',['SameInternalConfig&lt; ChildT1, Dim1, InternalNode&lt; ChildT2, Dim1 &gt; &gt;',['../structopenvdb_1_1v3__2__0_1_1tree_1_1SameInternalConfig_3_01ChildT1_00_01Dim1_00_01InternalNode_3_01ChildT2_00_01Dim1_01_4_01_4.html',1,'openvdb::v3_2_0::tree']]],
   ['sameleafconfig',['SameLeafConfig',['../structopenvdb_1_1v3__2__0_1_1tree_1_1SameLeafConfig.html',1,'openvdb::v3_2_0::tree']]],
@@ -54,8 +50,7 @@ var searchData=
   ['staggeredpointsampler',['StaggeredPointSampler',['../structopenvdb_1_1v3__2__0_1_1tools_1_1StaggeredPointSampler.html',1,'openvdb::v3_2_0::tools']]],
   ['staggeredquadraticsampler',['StaggeredQuadraticSampler',['../structopenvdb_1_1v3__2__0_1_1tools_1_1StaggeredQuadraticSampler.html',1,'openvdb::v3_2_0::tools']]],
   ['stashoriginandstoreoffset',['StashOriginAndStoreOffset',['../structopenvdb_1_1v3__2__0_1_1tools_1_1mesh__to__volume__internal_1_1StashOriginAndStoreOffset.html',1,'openvdb::v3_2_0::tools::mesh_to_volume_internal']]],
-  ['state',['State',['../structopenvdb_1_1v3__2__0_1_1math_1_1pcg_1_1State.html',1,'openvdb::v3_2_0::math::pcg']]],
-  ['state',['State',['../structopenvdb_1_1v3__2__0_1_1tools_1_1LevelSetTracker_1_1State.html',1,'openvdb::v3_2_0::tools::LevelSetTracker']]],
+  ['state',['State',['../structopenvdb_1_1v3__2__0_1_1math_1_1pcg_1_1State.html',1,'State'],['../structopenvdb_1_1v3__2__0_1_1tools_1_1LevelSetTracker_1_1State.html',1,'LevelSetTracker&lt; GridT, InterruptT &gt;::State']]],
   ['stats',['Stats',['../classopenvdb_1_1v3__2__0_1_1math_1_1Stats.html',1,'openvdb::v3_2_0::math']]],
   ['statsop',['StatsOp',['../structopenvdb_1_1v3__2__0_1_1tools_1_1stats__internal_1_1StatsOp.html',1,'openvdb::v3_2_0::tools::stats_internal']]],
   ['stealuniqueleafnodes',['StealUniqueLeafNodes',['../structopenvdb_1_1v3__2__0_1_1tools_1_1mesh__to__volume__internal_1_1StealUniqueLeafNodes.html',1,'openvdb::v3_2_0::tools::mesh_to_volume_internal']]],
