@@ -31,16 +31,10 @@ var searchData=
   ['checknan',['CheckNan',['../structopenvdb_1_1v3__2__0_1_1tools_1_1CheckNan.html',1,'openvdb::v3_2_0::tools']]],
   ['checknormgrad',['CheckNormGrad',['../structopenvdb_1_1v3__2__0_1_1tools_1_1CheckNormGrad.html',1,'openvdb::v3_2_0::tools']]],
   ['checkrange',['CheckRange',['../structopenvdb_1_1v3__2__0_1_1tools_1_1CheckRange.html',1,'openvdb::v3_2_0::tools']]],
-  ['childall',['ChildAll',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1ChildAll.html',1,'openvdb::v3_2_0::tree::InternalNode']]],
-  ['childall',['ChildAll',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1ChildAll.html',1,'openvdb::v3_2_0::tree::LeafNode']]],
-  ['childiter',['ChildIter',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1ChildIter.html',1,'openvdb::v3_2_0::tree::InternalNode']]],
-  ['childiter',['ChildIter',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1ChildIter.html',1,'openvdb::v3_2_0::tree::LeafNode']]],
-  ['childiter',['ChildIter',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_3_01bool_00_01Log2Dim_01_4_1_1ChildIter.html',1,'openvdb::v3_2_0::tree::LeafNode&lt; bool, Log2Dim &gt;']]],
-  ['childiter',['ChildIter',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_3_01ValueMask_00_01Log2Dim_01_4_1_1ChildIter.html',1,'openvdb::v3_2_0::tree::LeafNode&lt; ValueMask, Log2Dim &gt;']]],
-  ['childoff',['ChildOff',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1ChildOff.html',1,'openvdb::v3_2_0::tree::InternalNode']]],
-  ['childoff',['ChildOff',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1ChildOff.html',1,'openvdb::v3_2_0::tree::LeafNode']]],
-  ['childon',['ChildOn',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1ChildOn.html',1,'openvdb::v3_2_0::tree::InternalNode']]],
-  ['childon',['ChildOn',['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1ChildOn.html',1,'openvdb::v3_2_0::tree::LeafNode']]],
+  ['childall',['ChildAll',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1ChildAll.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildAll'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1ChildAll.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildAll']]],
+  ['childiter',['ChildIter',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1ChildIter.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildIter&lt; NodeT, ChildT, MaskIterT, TagT &gt;'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1ChildIter.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT, TagT &gt;'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_3_01bool_00_01Log2Dim_01_4_1_1ChildIter.html',1,'LeafNode&lt; bool, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT &gt;'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_3_01ValueMask_00_01Log2Dim_01_4_1_1ChildIter.html',1,'LeafNode&lt; ValueMask, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT &gt;']]],
+  ['childoff',['ChildOff',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1ChildOff.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildOff'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1ChildOff.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildOff']]],
+  ['childon',['ChildOn',['../structopenvdb_1_1v3__2__0_1_1tree_1_1InternalNode_1_1ChildOn.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildOn'],['../structopenvdb_1_1v3__2__0_1_1tree_1_1LeafNode_1_1ChildOn.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildOn']]],
   ['closestpointdist',['ClosestPointDist',['../classopenvdb_1_1v3__2__0_1_1tools_1_1internal_1_1ClosestPointDist.html',1,'openvdb::v3_2_0::tools::internal']]],
   ['closestpointprojector',['ClosestPointProjector',['../classopenvdb_1_1v3__2__0_1_1tools_1_1ClosestPointProjector.html',1,'openvdb::v3_2_0::tools']]],
   ['closestsurfacepoint',['ClosestSurfacePoint',['../classopenvdb_1_1v3__2__0_1_1tools_1_1ClosestSurfacePoint.html',1,'openvdb::v3_2_0::tools']]],
@@ -88,8 +82,7 @@ var searchData=
   ['copyop',['CopyOp',['../structopenvdb_1_1v3__2__0_1_1math_1_1pcg_1_1internal_1_1CopyOp.html',1,'openvdb::v3_2_0::math::pcg::internal']]],
   ['copytodense',['CopyToDense',['../classopenvdb_1_1v3__2__0_1_1tools_1_1CopyToDense.html',1,'openvdb::v3_2_0::tools']]],
   ['copytovecop',['CopyToVecOp',['../structopenvdb_1_1v3__2__0_1_1tools_1_1poisson_1_1internal_1_1CopyToVecOp.html',1,'openvdb::v3_2_0::tools::poisson::internal']]],
-  ['cpt',['Cpt',['../classopenvdb_1_1v3__2__0_1_1tools_1_1Cpt.html',1,'openvdb::v3_2_0::tools']]],
-  ['cpt',['CPT',['../structopenvdb_1_1v3__2__0_1_1math_1_1CPT.html',1,'openvdb::v3_2_0::math']]],
+  ['cpt',['Cpt',['../classopenvdb_1_1v3__2__0_1_1tools_1_1Cpt.html',1,'Cpt&lt; InGridT, MaskGridType, InterruptT &gt;'],['../structopenvdb_1_1v3__2__0_1_1math_1_1CPT.html',1,'CPT&lt; MapType, DiffScheme &gt;']]],
   ['cpt_5frange',['CPT_RANGE',['../structopenvdb_1_1v3__2__0_1_1math_1_1CPT__RANGE.html',1,'openvdb::v3_2_0::math']]],
   ['cputimer',['CpuTimer',['../classopenvdb_1_1v3__2__0_1_1util_1_1CpuTimer.html',1,'openvdb::v3_2_0::util']]],
   ['createorderedpointindexarrayop',['CreateOrderedPointIndexArrayOp',['../structopenvdb_1_1v3__2__0_1_1tools_1_1point__partitioner__internal_1_1CreateOrderedPointIndexArrayOp.html',1,'openvdb::v3_2_0::tools::point_partitioner_internal']]],
@@ -97,8 +90,7 @@ var searchData=
   ['csgintersectvisitor',['CsgIntersectVisitor',['../structopenvdb_1_1v3__2__0_1_1tools_1_1CsgIntersectVisitor.html',1,'openvdb::v3_2_0::tools']]],
   ['csgunionvisitor',['CsgUnionVisitor',['../structopenvdb_1_1v3__2__0_1_1tools_1_1CsgUnionVisitor.html',1,'openvdb::v3_2_0::tools']]],
   ['csgvisitorbase',['CsgVisitorBase',['../classopenvdb_1_1v3__2__0_1_1tools_1_1CsgVisitorBase.html',1,'openvdb::v3_2_0::tools']]],
-  ['curl',['Curl',['../classopenvdb_1_1v3__2__0_1_1tools_1_1Curl.html',1,'openvdb::v3_2_0::tools']]],
-  ['curl',['Curl',['../structopenvdb_1_1v3__2__0_1_1math_1_1Curl.html',1,'openvdb::v3_2_0::math']]],
+  ['curl',['Curl',['../classopenvdb_1_1v3__2__0_1_1tools_1_1Curl.html',1,'Curl&lt; GridT, MaskGridType, InterruptT &gt;'],['../structopenvdb_1_1v3__2__0_1_1math_1_1Curl.html',1,'Curl&lt; MapType, DiffScheme &gt;']]],
   ['curl_3c_20uniformscalemap_2c_20cd_5f2nd_20_3e',['Curl&lt; UniformScaleMap, CD_2ND &gt;',['../structopenvdb_1_1v3__2__0_1_1math_1_1Curl_3_01UniformScaleMap_00_01CD__2ND_01_4.html',1,'openvdb::v3_2_0::math']]],
   ['curl_3c_20uniformscalemap_2c_20diffscheme_20_3e',['Curl&lt; UniformScaleMap, DiffScheme &gt;',['../structopenvdb_1_1v3__2__0_1_1math_1_1Curl_3_01UniformScaleMap_00_01DiffScheme_01_4.html',1,'openvdb::v3_2_0::math']]],
   ['curl_3c_20uniformscaletranslatemap_2c_20cd_5f2nd_20_3e',['Curl&lt; UniformScaleTranslateMap, CD_2ND &gt;',['../structopenvdb_1_1v3__2__0_1_1math_1_1Curl_3_01UniformScaleTranslateMap_00_01CD__2ND_01_4.html',1,'openvdb::v3_2_0::math']]],
