@@ -8,8 +8,7 @@ var searchData=
   ['math_2eh',['Math.h',['../Math_8h.html',1,'']]],
   ['math_2etxt',['math.txt',['../math_8txt.html',1,'']]],
   ['meshtovolume_2eh',['MeshToVolume.h',['../MeshToVolume_8h.html',1,'']]],
-  ['metadata_2eh',['Metadata.h',['../Metadata_8h.html',1,'']]],
-  ['metadata_2eh',['Metadata.h',['../metadata_2Metadata_8h.html',1,'']]],
+  ['metadata_2eh',['Metadata.h',['../Metadata_8h.html',1,'(Global Namespace)'],['../metadata_2Metadata_8h.html',1,'(Global Namespace)']]],
   ['metamap_2eh',['MetaMap.h',['../MetaMap_8h.html',1,'']]],
   ['morphology_2eh',['Morphology.h',['../Morphology_8h.html',1,'']]],
   ['multiresgrid_2eh',['MultiResGrid.h',['../MultiResGrid_8h.html',1,'']]]
